@@ -11,4 +11,6 @@ google_app_credentials = os.environ.get('GOOGLE_APPLICATION_CREDENTIALS')
 portal_url = os.environ.get('PORTAL_URL')
 service_account_email = os.environ.get('SERVICE_ACCOUNT_EMAIL')
 service_account_password = os.environ.get('SERVICE_ACCOUNT_PASSWORD')
-save_inbox_leads = os.environ.get('SAVE_INBOX_LEADS', "false") == "true"
+v2_server_host = os.environ.get('V2_SERVER_HOST')
+v3_server_host = os.environ.get('V3_SERVER_HOST')
+v1_server_host = os.environ.get('V1_SERVER_HOST')
